TrackData

Struct TrackData 

pub struct TrackData<'a> {
    data: FontData<'a>,
}
The tracking data table.

Fields

data: FontData<'a>

Implementations

Source

impl<'a> TrackData<'a>

pub const MIN_SIZE: usize

pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>

Resolve the provided offset from the start of this table.

pub fn offset_data(&self) -> FontData<'a>

Return a reference to this table’s raw data.

We use this in the compile crate to resolve offsets.

pub fn shape(&self) -> &Self

👎Deprecated: just use the base type directly

Return a reference to the table’s ‘Shape’ struct.

This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.

pub fn n_tracks(&self) -> u16

Number of separate tracks included in this table.

pub fn n_sizes(&self) -> u16

Number of point sizes included in this table.

pub fn size_table_offset(&self) -> u32

Offset from the start of the tracking table to the start of the size subtable.

pub fn track_table(&self) -> &'a [TrackTableEntry]

Array of TrackTableEntry records.

pub fn n_tracks_byte_range(&self) -> Range<usize>

pub fn n_sizes_byte_range(&self) -> Range<usize>

pub fn size_table_offset_byte_range(&self) -> Range<usize>

pub fn track_table_byte_range(&self) -> Range<usize>

Source

impl<'a> TrackData<'a>

pub fn size_table( &self, offset_data: FontData<'a>, ) -> Result<&'a [BigEndian<Fixed>], ReadError>

Returns the size table for this set of tracking data.

The offset_data parameter comes from the Trak table.